"""Add Edge Port and GÉANT IP workflows.

Revision ID: bf05800fe9fc
Revises: a08bf228f112
Create Date: 2024-10-08 11:22:00.038925

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = 'bf05800fe9fc'
down_revision = 'a08bf228f112'
branch_labels = None
depends_on = None


from orchestrator.migrations.helpers import create_workflow, delete_workflow

new_workflows = [
    {
        "name": "create_edge_port",
        "target": "CREATE",
        "description": "Create Edge Port",
        "product_type": "EdgePort"
    },
    {
        "name": "modify_edge_port",
        "target": "MODIFY",
        "description": "Modify Edge Port",
        "product_type": "EdgePort"
    },
    {
        "name": "terminate_edge_port",
        "target": "TERMINATE",
        "description": "Terminate Edge Port",
        "product_type": "EdgePort"
    },
    {
        "name": "validate_edge_port",
        "target": "SYSTEM",
        "description": "Validate Edge Port Configuration",
        "product_type": "EdgePort"
    },
    {
        "name": "create_imported_edge_port",
        "target": "CREATE",
        "description": "Import Edge Port",
        "product_type": "ImportedEdgePort"
    },
    {
        "name": "import_edge_port",
        "target": "MODIFY",
        "description": "Import Edge Port",
        "product_type": "ImportedEdgePort"
    },
    {
        "name": "create_geant_ip",
        "target": "CREATE",
        "description": "Create G\u00c9ANT IP",
        "product_type": "GeantIP"
    },
    {
        "name": "modify_geant_ip",
        "target": "MODIFY",
        "description": "Modify G\u00c9ANT IP",
        "product_type": "GeantIP"
    },
    {
        "name": "create_imported_geant_ip",
        "target": "CREATE",
        "description": "Import G\u00c9ANT IP",
        "product_type": "ImportedGeantIP"
    },
    {
        "name": "import_geant_ip",
        "target": "MODIFY",
        "description": "Import G\u00c9ANT IP",
        "product_type": "ImportedGeantIP"
    }
]


def upgrade() -> None:
    conn = op.get_bind()
    for workflow in new_workflows:
        create_workflow(conn, workflow)


def downgrade() -> None:
    conn = op.get_bind()
    for workflow in new_workflows:
        delete_workflow(conn, workflow["name"])
