"""A modification workflow for migrating an ImportedGeantIP to an GeantIP subscription."""

from orchestrator.targets import Target
from orchestrator.types import State, UUIDstr
from orchestrator.workflow import StepList, done, init, step, workflow
from orchestrator.workflows.steps import resync, store_process_subscription, unsync
from orchestrator.workflows.utils import wrap_modify_initial_input_form

from gso.products import ProductName
from gso.products.product_types.geant_ip import GeantIP, ImportedGeantIP
from gso.services.subscriptions import get_product_id_by_name


@step("Create new IP trunk subscription")
def import_geant_ip_subscription(subscription_id: UUIDstr) -> State:
    """Take an ImportedGeantIP subscription, and turn it into an GeantIP subscription."""
    old_geant_ip = ImportedGeantIP.from_subscription(subscription_id)
    new_subscription_id = get_product_id_by_name(ProductName.IP_TRUNK)
    new_subscription = GeantIP.from_other_product(old_geant_ip, new_subscription_id)  # type: ignore[arg-type]

    return {"subscription": new_subscription}


@workflow("Import GÉANT IP", target=Target.MODIFY, initial_input_form=wrap_modify_initial_input_form(None))
def import_geant_ip() -> StepList:
    """Modify an ImportedGeantIP subscription into an GeantIP subscription to complete the import."""
    return init >> store_process_subscription(Target.MODIFY) >> unsync >> import_geant_ip_subscription >> resync >> done
